Login | Register For Free | Help
Search for: (Advanced)

Mailing List Archive: Cherokee: commits

[3851] cherokee/trunk/admin/PageVServer.py: Adds a new field for the timeout in the rules table.

 

 

Cherokee commits RSS feed   Index | Next | Previous | View Threaded


cherokee at cherokee-project

Nov 20, 2009, 7:47 AM

Post #1 of 1 (103 views)
Permalink
[3851] cherokee/trunk/admin/PageVServer.py: Adds a new field for the timeout in the rules table.

Revision: 3851
http://svn.cherokee-project.com/changeset/3851
Author: alo
Date: 2009-11-20 16:47:36 +0100 (Fri, 20 Nov 2009)

Log Message:
-----------
Adds a new field for the timeout in the rules table.

Modified Paths:
--------------
cherokee/trunk/admin/PageVServer.py

Modified: cherokee/trunk/admin/PageVServer.py
===================================================================
--- cherokee/trunk/admin/PageVServer.py 2009-11-20 14:34:56 UTC (rev 3850)
+++ cherokee/trunk/admin/PageVServer.py 2009-11-20 15:47:36 UTC (rev 3851)
@@ -346,7 +346,8 @@
DISABLED_IMAGE = self.InstanceImage('cross.png', _('No'))

txt += '<table id="%s" class="rulestable">' % (table_name)
- txt += '<tr class="nodrag nodrop"><th>&nbsp;</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th></th></tr>' % (_('Target'), _('Type'), _('Handler'), _('Root'), _('Auth'), _('Enc'), _('Exp'), _('Final'))
+ txt += '<tr class="nodrag nodrop"><th>&nbsp;</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th></th></tr>' %(
+ _('Target'), _('Type'), _('Handler'), _('Root'), _('Auth'), _('Enc'), _('Exp'), _('Time'), _('Final'))

# Rule list
for prio in priorities:
@@ -389,6 +390,7 @@

expiration = [DISABLED_IMAGE, ENABLED_IMAGE]['expiration' in conf.keys()]
document_root = [DISABLED_IMAGE, ENABLED_IMAGE]['document_root' in conf.keys()]
+ timeout = [DISABLED_IMAGE, ENABLED_IMAGE]['timeout' in conf.keys()]

encoders = DISABLED_IMAGE
if 'encoder' in conf.keys():
@@ -396,8 +398,8 @@
if int(conf.get_val('encoder!%s'%(k))):
encoders = ENABLED_IMAGE

- txt += '<!-- %s --><tr prio="%s" id="%s"%s><td%s>&nbsp;</td><td>%s</td><td>%s</td><td>%s</td><td class="center">%s</td><td class="center">%s</td><td class="center">%s</td><td class="center">%s</td><td class="center">%s</td><td class="center">%s</td></tr>\n' % (
- prio, pre, prio, extra, draggable, link, name_type, handler_name, document_root, auth_name, encoders, expiration, final, link_del)
+ txt += '<!-- %s --><tr prio="%s" id="%s"%s><td%s>&nbsp;</td><td>%s</td><td>%s</td><td>%s</td><td class="center">%s</td><td class="center">%s</td><td class="center">%s</td><td class="center">%s</td><td class="center">%s</td><td class="center">%s</td><td class="center">%s</td></tr>\n' % (
+ prio, pre, prio, extra, draggable, link, name_type, handler_name, document_root, auth_name, encoders, expiration, timeout, final, link_del)

txt += '</table>\n'

Cherokee commits RSS feed   Index | Next | Previous | View Threaded
 
 


Interested in having your list archived? Contact Gossamer Threads
 
  Web Applications & Managed Hosting Powered by Gossamer Threads Inc.